unit OtaUtils;

interface

 uses
   toolsAPI,classes, menus, ActnList, comctrls, imglist, graphics,Dsgnintf, sysutils, windows;

function GetActionServices: IOTAActionServices;

function GetDebuggerServices: IOTADebuggerServices;

function GetMessageServices: IOTAMessageServices;

function GetModuleServices: IOTAModuleServices;

function GetPackageServices: IOTAPackageServices;

function GetNTAServices: INTAServices;

function GetOTAServices: IOTAServices;

function GetWizardServices: IOTAWizardServices;

function GetCurrentModule: IOTAModule;

function GetModuleCount: Integer;

function GetModule(const Index: Integer): IOTAModule;

function GetBaseRegistryKey: string;

function GetProductIdentifier: string;

function GetEnvironmentOptions: IOTAEnvironmentOptions;

function AddNotifier(const Notifier: IOTAIDENotifier): Integer;overload;

procedure RemoveIDENotifier(const Index: Integer);

function GetMainMenu: TMainMenu;

function GetToolBar(const ToolBarName: string): TToolBar;

function GetImageList: TCustomImageList;

function GetActionList: TCustomActionList;

function AddMasked(Image : Graphics.TBitmap; MaskColor: TColor): Integer;

function GetFileName: string;

function GetFileSystem: string;

function GetOwner(const Index: Integer): IOTAProject;

function GetOwnerCount: Integer;

procedure SetFileName(const FileName: string);

procedure SetFileSystem(const FileSystem: string);

function GetProjectGroup: IOTAProjectGroup;

function GetActiveProject: IOTAProject;

function GetProjectCount: Integer;

function GetProject(const Index: Integer): IOTAProject;

procedure SetActiveProject(const Project: IOTAProject);

procedure AddNewProject;

procedure AddExistingProject;

procedure RemoveProject(const Project: IOTAProject);

function GetProjectModuleCount: Integer;

function GetModuleInfo(const Index: Integer): IOTAModuleInfo;

function GetProjectOptions: IOTAProjectOptions;

function GetProjectBuilder: IOTAProjectBuilder;

function GetShouldBuild: Boolean;

function BuildProject(Mode: TOTACompileMode; Wait, ClearMessages: Boolean): Boolean;

function GetModuleFileCount: Integer;

function GetModuleFileEditor(const Index: Integer): IOTAEditor;

function Close: Boolean;

function Save(ChangeName, ForceSave: Boolean): Boolean;

function AddNotifier(const Notifier: IOTAModuleNotifier): Integer;overload;

procedure RemoveModuleNotifier(const Index: Integer);

function GetFormEditor: IOTAFormEditor;


function GetFormFileName: string;

function GetFormModified: Boolean;

function GetFormModule: IOTAModule;

function GetRootComponent: IOTAComponent;

function FindComponent(const Name: string): IOTAComponent;

function GetNTAFormEditor: INTAFormEditor;

function GetFormDesigner: IFormDesigner;

procedure GetNTAFormResource(Stream: TStream);

function GetTComponent(const OTAComponent: IOTAComponent): TComponent;

function FindModuleInterface(AInterface: TGUID): IUnknown;




implementation


function GetActionServices: IOTAActionServices;
begin
   Result := BorlandIDEServices as IOTAActionServices;
end;

function GetDebuggerServices: IOTADebuggerServices;
begin
  Result := BorlandIDEServices as IOTADebuggerServices;
end;

function GetMessageServices: IOTAMessageServices;
begin
  Result := BorlandIDEServices as IOTAMessageServices;
end;

function GetModuleServices: IOTAModuleServices;
begin
  Result := BorlandIDEServices as IOTAModuleServices;
end;

function GetPackageServices: IOTAPackageServices;
begin
  Result := BorlandIDEServices as IOTAPackageServices;
end;

function GetNTAServices: INTAServices;
begin
  Result := BorlandIDEServices as INTAServices;
end;

function GetOTAServices: IOTAServices;
begin
//  Result := BorlandIDEServices as IOTADebuggerServices;
Result := nil;
end;

function GetWizardServices: IOTAWizardServices;
begin
  Result := BorlandIDEServices as IOTAWizardServices;
end;

function GetCurrentModule: IOTAModule;
begin
  Result := GetModuleServices.CurrentModule;
  if not Assigned(Result) then
    raise Exception.Create('No CurrentModule available');
end;

function GetModuleCount: Integer;
begin
  Result := GetModuleServices.GetModuleCount;
end;

function GetModule(const Index: Integer): IOTAModule;
begin
  Result := GetModuleServices.GetModule(Index);
end;

function GetBaseRegistryKey: string;
begin
  Result := GetOTAServices.GetBaseRegistryKey;
end;

function GetProductIdentifier: string;
begin
  Result := GetOTAServices.GetProductIdentifier;
end;

function GetEnvironmentOptions: IOTAEnvironmentOptions;
begin
  Result := GetOTAServices.GetEnvironmentOptions;
end;

function AddNotifier(const Notifier: IOTAIDENotifier): Integer;
begin
  Result := GetOTAServices.AddNotifier(Notifier);
end;

procedure RemoveIDENotifier(const Index: Integer);
begin
  GetOTAServices.RemoveNotifier(Index);
end;


function GetMainMenu: TMainMenu;
begin
  Result := GetNTAServices.GetMainMenu;
end;

function GetToolBar(const ToolBarName: string): TToolBar;
begin
  Result := GetNTAServices.GetToolBar(ToolBarName);
end;

function GetImageList: TCustomImageList;
begin
  Result := GetNTAServices.GetImageList;
end;

function GetActionList: TCustomActionList;
begin
  Result := GetNTAServices.GetActionList;
end;

function AddMasked(Image: Graphics.TBitmap; MaskColor: TColor): Integer;
begin
  Result := GetNTAServices.AddMasked(Image, MaskColor);
end;

function GetFileName: string;
begin
  Result := GetCurrentModule.GetFileName;
end;

function GetFileSystem: string;
begin
  Result := GetCurrentModule.GetFileSystem;
  if (trim(Result) = '') then
   raise Exception.Create('No FileSystem available');
end;

function GetOwner(const Index: Integer): IOTAProject;
begin
  Result := GetCurrentModule.GetOwner(Index);
end;

function GetOwnerCount: Integer;
begin
  Result := GetCurrentModule.GetOwnerCount;
end;

procedure SetFileName(const FileName: string);
begin
  GetCurrentModule.SetFileName(FileName);
end;

procedure SetFileSystem(const FileSystem: string);
begin
  GetCurrentModule.SetFileSystem(FileSystem);
end;

function GetProjectGroup: IOTAProjectGroup;
var
  ModuleServices: IOTAModuleServices;
  Module: IOTAModule;
  ProjectGroup: IOTAProjectGroup;
  i: Integer;
begin
  ModuleServices := GetModuleServices;
  for i := 0 to ModuleServices.ModuleCount - 1 do
  begin
    Module := ModuleServices.Modules[i];
    if (Module.QueryInterface(IOTAProjectGroup, ProjectGroup) = S_OK) then     Break;
  end;
  Result := ProjectGroup;
  ModuleServices := nil;
  Module := nil;
  ProjectGroup := nil;
  if not Assigned(Result) then
     raise Exception.Create('No ProjectGroup available');
end;

function GetActiveProject: IOTAProject;
begin
  Result := GetProjectGroup.GetActiveProject;
  if not Assigned(Result) then
    raise Exception.Create('No Project available');
end;

function GetProjectCount: Integer;
begin
  Result := GetProjectGroup.GetProjectCount;
end;

function GetProject(const Index: Integer): IOTAProject;
begin
  Result := GetProjectGroup.GetProject(Index);
end;

procedure SetActiveProject(const Project: IOTAProject);
begin
  GetProjectGroup.SetActiveProject(Project);
end;

procedure AddNewProject;
begin
  GetProjectGroup.AddNewProject;
end;

procedure AddExistingProject;
begin
  GetProjectGroup.AddExistingProject;
end;

procedure RemoveProject(const Project: IOTAProject);
begin
  GetProjectGroup.RemoveProject(Project);
end;

function GetProjectModuleCount: Integer;
begin
  Result := GetActiveProject.GetModuleCount;
end;

function GetModuleInfo(const Index: Integer): IOTAModuleInfo;
begin
  Result := GetActiveProject.GetModule(Index);
end;

function GetProjectOptions: IOTAProjectOptions;
begin
  Result := GetActiveProject.GetProjectOptions;
end;

function GetProjectBuilder: IOTAProjectBuilder;
begin
  Result := GetActiveProject.GetProjectBuilder;
end;

function GetShouldBuild: Boolean;
begin
  Result := GetProjectBuilder.ShouldBuild;
end;

function BuildProject(Mode: TOTACompileMode; Wait, ClearMessages: Boolean): Boolean;
begin
   Result := GetProjectBuilder.BuildProject(Mode, Wait, ClearMessages);
end;

function GetModuleFileCount: Integer;
begin
  Result := GetCurrentModule.GetModuleFileCount;
end;

function GetModuleFileEditor(const Index: Integer): IOTAEditor;
begin
  if (GetCurrentModule.GetModuleFileCount = 0) then
     raise Exception.Create('No FileModule available');
  Result := GetCurrentModule.GetModuleFileEditor(Index);
end;

function Close: Boolean;
begin
  Result := GetCurrentModule.Close;
end;

function Save(ChangeName, ForceSave: Boolean): Boolean;
begin
  Result := GetCurrentModule.Save(ChangeName, ForceSave);
end;

function AddNotifier(const Notifier: IOTAModuleNotifier): Integer;
begin
  Result := GetCurrentModule.AddNotifier(Notifier);
end;

procedure RemoveModuleNotifier(const Index: Integer);
begin
  GetCurrentModule.RemoveNotifier(Index);
end;

function GetFormEditor: IOTAFormEditor;
var
  Module: IOTAModule;
  Editor: IOTAEditor;
  FormEditor: IOTAFormEditor;
  i: Integer;
begin
  FormEditor := nil;
  Module := GetCurrentModule;
  for i := 0 to Module.GetModuleFileCount - 1 do
  begin
    Editor := Module.GetModuleFileEditor(i);
    if not Assigned(Editor) then
      raise Exception.Create('No ModuleFileEditor available');
    if (Editor.QueryInterface(IOTAFormEditor, FormEditor) = S_OK) then
      Break;
  end;
  Result := FormEditor;
  Module := nil;
  Editor := nil;
  FormEditor := nil;
  if not Assigned(Result) then
    raise Exception.Create('No FormEditor available');
end;

function GetFormFileName: string;
begin
  Result := GetFormEditor.FileName;
end;

function GetFormModified: Boolean;
begin
  Result := GetFormEditor.Modified;
end;

function GetFormModule: IOTAModule;
begin
  Result := GetFormEditor.Module;
end;

function GetRootComponent: IOTAComponent;
begin
  Result := GetFormEditor.GetRootComponent;
end;

function FindComponent(const Name: string): IOTAComponent;
begin
  Result := GetFormEditor.FindComponent(Name);
end;

function GetNTAFormEditor: INTAFormEditor;
begin
  Result := GetFormEditor as INTAFormEditor;
end;

function GetFormDesigner: IFormDesigner;
begin
  Result := GetNTAFormEditor.GetFormDesigner;
  if not Assigned(Result) then
    raise Exception.Create('No FormDesigner available');
end;

procedure GetNTAFormResource(Stream: TStream);
begin
  GetNTAFormEditor.GetFormResource(Stream);
end;

function GetTComponent(const OTAComponent: IOTAComponent): TComponent;
begin
  Result := (OTAComponent as INTAComponent).GetComponent;
end;

function FindModuleInterface(AInterface: TGUID): IUnknown;
var
  i: Integer;
begin
  Result := nil;
  with GetModuleServices do
  for i := 0 to ModuleCount - 1 do
    if (Modules[i].QueryInterface(AInterface, Result) = S_OK) then
      Break;
end;

//Result := FindModuleInterface(IOTAProjectGroup) as IOTAProjectGroup;
//Result := FindModuleInterface(IOTAProject) as IOTAProject;


end.
